---
title: <span class="badge object-type-scalar"></span> Microsievert
---
# <span class="badge object-type-scalar"></span> Microsievert

Radiation: microSievert (µSv)

## Definition

```python
# Radiation: microSievert (µSv)
Microsievert: typing.Literal["radusv"] = "radusv"
```
